EnvBaseVisitor<T> class

This class provides an empty implementation of EnvVisitor, which can be extended to create a visitor which only needs to handle a subset of the available methods.

T is the return type of the visit operation. Use void for operations with no return type.

Implemented types
Implementers

Constructors

EnvBaseVisitor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregateResult(T? aggregate, T? nextResult) → T?
Aggregates the results of visiting multiple children of a node. After either all children are visited or {@link #shouldVisitNextChild} returns false, the aggregate value is returned as the result of {@link #visitChildren}.
inherited
defaultResult() → T?
Gets the default value returned by visitor methods. This value is returned by the default implementations of {@link #visitTerminal visitTerminal}, {@link #visitErrorNode visitErrorNode}. The default implementation of {@link #visitChildren visitChildren} initializes its aggregate result to this value.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldVisitNextChild(RuleNode node, T? currentResult) → bool
This method is called after visiting each child in {@link #visitChildren}. This method is first called before the first child is visited; at that point currentResult will be the initial value (in the default implementation, the initial value is returned by a call to {@link #defaultResult}. This method is not called after the last child is visited.
inherited
toString() → String
A string representation of this object.
inherited
visit(ParseTree tree) → T?
{@inheritDoc}
inherited
visitChildren(RuleNode node) → T?
{@inheritDoc}
inherited
visitComment(CommentContext ctx) → T?
The default implementation returns the result of calling visitChildren on ctx.
override
visitEnv(EnvContext ctx) → T?
The default implementation returns the result of calling visitChildren on ctx.
override
visitErrorNode(ErrorNode node) → T?
{@inheritDoc}
inherited
visitKey(KeyContext ctx) → T?
The default implementation returns the result of calling visitChildren on ctx.
override
visitLine(LineContext ctx) → T?
The default implementation returns the result of calling visitChildren on ctx.
override
visitString(StringContext ctx) → T?
The default implementation returns the result of calling visitChildren on ctx.
override
visitTerminal(TerminalNode node) → T?
{@inheritDoc}
inherited
visitValue(ValueContext ctx) → T?
The default implementation returns the result of calling visitChildren on ctx.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited