KeyValue class

Constructors

KeyValue({required String name, required String type, required dynamic value, required List<String> comments, bool nullable = false})

Properties

comments ↔ List<String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
nullable ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair
value ↔ dynamic
getter/setter pair

Methods

copyWith({String? name, List<String>? comments, String? type, Object? value, bool? nullable}) → KeyValue
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited